const moment = require('moment');
const { models } = require('./models/index.js');
const vnUtils = require('./utils.js');
require('dotenv').config()
// const cliProgress = require('cli-progress');

async function main() {
    console.log = function () {
        let args = Array.prototype.slice.call(arguments);
        args.unshift(new moment().format('HH:mm:ss') + ' -');
        console.info.apply(console, args);
    };

    let tokenExpirationDate = vnUtils.getClientToken(models);

    process.env.syncSequence ? await vnUtils.syncSequence() : null;
    process.env.syncSupplier ? await vnUtils.syncSuppliers() : null;
    await vnUtils.syncConnections();
    process.env.syncTradeItem ? await vnUtils.syncTradeItems() : null;
    console.log('Synced trade items');

    try {
        // eslint-disable-next-line no-constant-condition
        while (true) {
            try{
                console.log('Querying the API to check for new data...');
                console.log('Current token expiration date: ', tokenExpirationDate);
                
                if (moment().isAfter(tokenExpirationDate)) {
                    console.log('Token expired, getting a new one...');
                    tokenExpirationDate = await vnUtils.getClientToken(models);
                }
                
                await vnUtils.syncSupplyLines();

            } catch (error) {
                console.error(error);
            }

            if (process.env.environment == 'development') {
                await vnUtils.sleep(120000);
            } else {
                await vnUtils.sleep(300000);
            }
        }

    } catch (error) {
        console.error('Unable to connect to the database:', error);
    }
}
main();